@@ -10,7 +10,7 @@
 #' @export
 #'
 row <- function(...) {
-  htmltools::tags$div(class = "row", ...)
+  htmltools::tags$div(class = "row card-pro-row", ...)
 }
 
 
@@ -25,11 +25,14 @@ row <- function(...) {
 #' @param fontawesome option. logical. include fontawesome
 #' @param fix.header logical. fix header if titlePanel2() is used in UI
 #'
+#' @note
+#' Theme options are "a", "b", "c", "d" or "e"
+#'
 #' @return A list of files to be inserted in the header of a page
 #' @examples
 #' if(interactive()){
 #' use.cardpro()
-#' use.cardpro(theme="a",jqueryui = T, fontawesome = F)
+#' use.cardpro(theme="a",jqueryui = TRUE, fontawesome = FALSE)
 #' }
 #' @export
 #'
@@ -64,7 +67,7 @@ use.cardpro <-
         )
       ),
       if(file.exists("www/myscript.js")){htmltools::tags$script(src="myscript.js")},
-      if(file.exists("www/myscript.css")){htmltools::tags$link(href="myscript.css")},
+      if(file.exists("www/myscript.css")){htmltools::tags$link(rel="stylesheet", type="text/css", href="myscript.css")},
       htmltools::tags$link(
         href = ifelse(
           fontawesome,
@@ -105,7 +108,7 @@ nav <- function(class,
                 role = NULL,
                 ...) {
   shiny::HTML(paste0(
-    "<nav class='",
+    "<nav class='card-pro-nav ",
     class,
     "' id='",
     id,
